==> vapeplot-0.0.2.tar.gz: vapeplot-0.0.2/README.md <==
# vapeplot

---

matplotlib extension for vaporwave aesthetics 

---

## install

```
pip install vapeplot
```

---

## demo

#### view all palettes

```
import vapeplot
%matplotlib inline

vapeplot.available()
```

![alt text](https://raw.githubusercontent.com/dantaki/vapeplot/master/vapeplot.png "vapeplot palettes")

#### view specific palettes

```
vapeplot.view_palette("cool",'sunset')
```

![alt text](https://raw.githubusercontent.com/dantaki/vapeplot/master/view_palette.png "cool sunset")

#### set the color palette

```
import numpy as np
import matplotlib.pyplot as plt

vapeplot.set_palette('vaporwave')
for i in range(10):
    plt.plot(range(100),np.random.normal(i,1,100))
vapeplot.despine(plt.axes()) #remove right and top axes
```

![alt test](https://raw.githubusercontent.com/dantaki/vapeplot/master/vaporwave.png "vaporwave palette")

#### access a palette

```
# cool is a list of colors
cool = vapeplot.pal().cool

# reverse the order of colors
seapunk_r = list(reversed(vapeplot.pal().seapunk))

```

---

## api

* `vapeplot.pal()`
  * object of palettes 
  * attribute is the palette name
  * value is a list of colors

  * `vapeplot.pal().macplus # returns a list of macplus colors`


* `vapeplot.available(show=True)`
  * function to plot all vapeplot palettes
  * `show=False` prints palette names


* `vapeplot.despine(ax,all=False)` 
  * removes figure axes
  * default action: remove right and top axes
  * `all=True` removes all axes


* `vapeplot.font_size(s)`
  * change the font size globally


* `vapeplot.set_palette(palname)`
  * change the color palette globally
  * `palname` is the name of the color palette

* `vapeplot.view_palette*args)`
  * view individual palettes
  * arguments: one or more palette names

---


## more to come :wink:

==> vapeplot-0.0.3.tar.gz: vapeplot-0.0.3/README.md <==
# vapeplot

---

matplotlib extension for vaporwave aesthetics 

---

## install

```
pip install vapeplot
```

---

## demo

#### view all palettes

```
import vapeplot
%matplotlib inline

vapeplot.available()
```

![alt text](https://raw.githubusercontent.com/dantaki/vapeplot/master/vapeplot.png "vapeplot palettes")

#### view specific palettes

```
vapeplot.view_palette("cool",'sunset')
```

![alt text](https://raw.githubusercontent.com/dantaki/vapeplot/master/view_palette.png "cool sunset")

#### set the color palette

```
import numpy as np
import matplotlib.pyplot as plt

vapeplot.set_palette('vaporwave')
for i in range(10):
    plt.plot(range(100),np.random.normal(i,1,100))
vapeplot.despine(plt.axes()) #remove right and top axes
```

![alt test](https://raw.githubusercontent.com/dantaki/vapeplot/master/vaporwave.png "vaporwave palette")

#### make a colormap

```
cmap = vapeplot.cmap('crystal_pepsi')
A = np.random.rand(25, 25)
plt.imshow(A,cmap=cmap)
# remove all axes
vapeplot.despine(plt.axes(),True)
plt.show()
```

![alt text](https://raw.githubusercontent.com/dantaki/vapeplot/master/vapeplot_colormaps.png "crystal_pepsi colormap")


#### access a palette

```
# cool is a list of colors
cool = vapeplot.palette("cool")

# reverse the order of colors
seapunk_r = vapeplot.reverse("seapunk")

```

---

## api

* `vapeplot.available(show=True)`
  * function to plot all vapeplot palettes
  * `show=False` prints palette names


* `vapeplot.cmap(palname)`
  * returns a colormap object
  * `palname` is the name of the color palette


* `vapeplot.despine(ax,all=False)` 
  * removes figure axes
  * default action: remove right and top axes
  * `all=True` removes all axes


* `vapeplot.font_size(s)`
  * change the font size globally


* `vapeplot.palette(palname)`
  * returns a list of colors
  * if no `palname` is given, a dict of all the palettes is returned


* `vapeplot.reverse(palname)`
  * returns a list of colors in reverse



* `vapeplot.set_palette(palname)`
  * change the color palette globally



* `vapeplot.view_palette(*args)`
  * view individual palettes
  * arguments: one or more palette names

---


## more to come :wink:
